157,087 Commits over 4,566 Days - 1.43cph!
Monument blockers outside military tunnels now require explosives to break through, same as the ones in front of red card rooms
exported warhead garage door anims
merge from firstperson_turnanims
Add turn in place anims for first person view. off by default and convared behind `turninplacefp` for now
merge from headik_wounded_fix
fix head ik looking weird while downed
Scrap king skin texture progress / modified the layout to be slightly less busy
Merge from render_pipeline_testing
Update gamepad_manifest command to work in builds
Setup hot overlay and doublevision effect
Fix frost post effect to match BIRP
Actually make that readwrite
Change deferred light pass from WriteAll to Write
Merge from hemp_colour_swap
Added the settings option
Added an acessibility tool to swap the colour of hemp plants found in the wild (farmed
Removed an unused LOD level from the hemp collectable
Merge from sprint_metabolism
Double calorie/fluid consumption when sprinting, controlled by server.sprintmetabolismscale (2 by default, set to 1 for legacy behaviour)
Also added a missing partial to EffectRecycle
Fix distance flares getting (permanently?) stuck off sometimes
merge from fix_switch_ammo_reload -> main
Fix guns with partial reloads (shotguns) not reloading all the bullets after switching ammo
- example: 4 buckshot loaded, switch to slugs and it only reloads 4
Merge from SpiralStaircaseFix2
▋██▊▉▆ ▊▊▍▇ ▌█▉▉▆▍▄▍▅▇▄█▉▌▋▉▍▇▍▋▋▆
Merge from SeedExtraction
Merge from icon_render_legacy_bindpose_fix
Workshop skin textures no longer keep a copy in RAM
Downloaded skin textures were left readable, nothing used that copy
98MB -> 0MB RAM with 22 skins loaded ingame
Added support for a base melee to forward signals to a world animator, enabled on shears
reapplied berry extraction, undid another change I accidentally included i
Added 'Extract' option on berries to get seeds without having to eat the berries. 1 berry gives 1 seed.
▉███▄▉ ▆▊▋▊ █▊▋▇▆▊▌▋▌▉▊▍▌▇▋▅▇▅▆▊▅▊▄▅▅▆
▇▅▌▋█▉▊▊ ▋▋▊ ▇▆▅▊▊█▋▊█▊ ▍█▉▄▄█▆▄ ▆▅ █▌▍▇▌▍▉▌▇▍▊ ▍▇█▋▋▋▄▍ ▋▊▇▅ █▇ ▊▇▋█▄ ▇▊▉ ▉▅▉▆▋▋▊▌▍▆ █▍▄▅▄▆▆▋▆▅█ ▉▅ ▋█▍▅▊▌▇▆ ▉▄█▋ ▇▆█▍▆▆▌ ▊ ▄▊▉ ▇▉▆▉▅▇▅▉▄ ▄▍▋▌▌▉▄ ▄ ▉▄▌▌▊▇▋▄▋▌▍ ▌▊▍▅ ▄ ▍▊▊▇▇▆▍ ▇▉█▋▇█▊ ▅▊▅▌▄▄▋▋▋▅█▉██▆ ▊█▅▌▋ ▍ ▅▍▊▋▇▄█ ▆▆▊▇▉▄▋ ▆▋ ▋▌ ▅▆▆▍█▌ ▋▋ █ ▅▍▍ ▊▉ ▋▋▍ ▋█▅▊▍▇██▉ ▅▍▇▋▍▍▊▆ ▊█▋▅ █▋▍ ▊▉▇▇ ▆▍▋▌ ▇▋ ▉▆▊▆▅ ▍▋ █▍▋ ▌▇▊▆▄▇ █▌ ▇▍▌ ▇▋▆ ▄▇▄▅ ▆▉▇▅▄▄▇ ▊▄▍▉█▍▋ █▍▄▆▌▄▇▌▉▌▉▇ ▍▆▉█▆ ▋▍▊▆▇█▋ ▇▊▌▇▇ █▇▌▄▄▌▋▅▋█▍ ▌█▍ █▉▊▅▅▅▉▋
Fixed our static font being set as readable
The atlases are only in VRAM now, saves another ~42MB RAM
Fixed fonts duped in memory:
- the interaction toast in bootstrap was using the non bootstrap version
- TMP Settings was referencing Roboto which was pulling the entire chain
Saves around ~60MB VRAM and ~30MB RAM
Add uploading of signs / sculptures / voicemails to our backend
- simple retry: try 1x per minute, give up after 5x attempts
Apply the same hierarchy flattening from S2P on all prefabs in PrefabPreProcess (only at bundle time, skipped in editor by default)
Fix some edge cases in the hierarchy flattening logic
▍ ▍▉▉█▇▌▉▄▌▍▍▉▌▆▍█▇▍█▇▋▍ ▌▍ ▅▅▌▌
▆ ▆▆▊ ▇█ ▌▄▍▉▆▍█▆ ▍▇▊▋ ▊▍▅
▋ ▄▉▇▍ ▊▇▉▌▅ ▉▅▋ ▊▆ ▋▆▅ ▊▉▄▇▆▇▍ ▋▉▊▅▆▉▉ ▍▅▆▋ ▇▉ ██▊▊ ▋▅█▇ ▆▉ ▍▇▇▅ ▍█ ▄█▋ ▅ █▆▄▋▇▉
Improved panel unregistration performance
▉▊▍▊▇▊ ▋█▌▆▊▍▆▉▊ ▋▌▅██ ▍ ▇▍▉▅▉▊ ▊▍▌▊█▊▍█▇▋▄▅▍▉█▅▆▆▇▉ █▆ ▇█▉▅ ▌█▆▋▇▉▋ ▍▅▉ ▄▊▆ ▆▇▅▆▄▋▄ ▉▌▉▅▊▇▌ ▍▆ █▉ ▇▄▆▌ █▆ ▊▇▉▇ ▍█▌ ▅▊▄ ▄▆▇▍▇▊ █▊▍▍▄▄▄ ▊▋▋ ▊▄ ▊▉▍▇▌▌ ▉▊▆ ▋▉█▊▄▍▇▋▋▌ █▆▊▉▉▍▉ ▆▊▆ ▌▉▆▋▌█▅▄ ▊██▇▊ █▋ ▄█▇▍ ▄▋▌▄▌▅▋ ▄▍██▆ ▊▍▇▇▅ ▇▊▋▊▌▇▄▆▇▄▉▅
merge from fix_cookable_created_alloc -> main